@@ -205,7 +205,7 @@ mutt_copy_hdr (FILE *in, FILE *out, long off_start, long off_end, int flags,
     if (headers[x])
     {
       if (flags & CH_DECODE)
-	rfc2047_decode (headers[x], headers[x], mutt_strlen (headers[x]) + 1);
+	rfc2047_decode (&headers[x]);
 
       /* We couldn't do the prefixing when reading because RFC 2047
        * decoding may have concatenated lines.
@@ -297,10 +297,6 @@ mutt_copy_header (FILE *in, HEADER *h, FILE *out, int flags, const char *prefix)
     rfc822_cat(buffer, sizeof(buffer), Charset, MimeSpecials);
     fputs(buffer, out);
     fputc('\n', out);
-    
-    if (ferror (out) != 0 || feof (out) != 0)
-      return -1;
-    
   }
 
   if (flags & CH_UPDATE)
@@ -366,9 +362,6 @@ mutt_copy_header (FILE *in, HEADER *h, FILE *out, int flags, const char *prefix)
       return (-1);
   }
 
-  if (ferror (out) || feof (out))
-    return -1;
-  
   return (0);
 }
 
@@ -460,7 +453,7 @@ _mutt_copy_message (FILE *fpout, FILE *fpin, HEADER *hdr, BODY *body,
 	new_lines = 0;
       else
 	fprintf (fpout, "Lines: %d\n\n", new_lines);
-      if (ferror (fpout) || feof (fpout))
+      if (ferror (fpout))
 	return -1;
       new_offset = ftell (fpout);
 
@@ -590,12 +583,7 @@ mutt_copy_message (FILE *fpout, CONTEXT *src, HEADER *hdr, int flags,
   
   if ((msg = mx_open_message (src, hdr->msgno)) == NULL)
     return -1;
-  if ((r = _mutt_copy_message (fpout, msg->fp, hdr, hdr->content, flags, chflags)) == 0 
-      && (ferror (fpout) || feof (fpout)))
-  {
-    dprint (1, (debugfile, "_mutt_copy_message failed to detect EOF!\n"));
-    r = -1;
-  }
+  r = _mutt_copy_message (fpout, msg->fp, hdr, hdr->content, flags, chflags);
   mx_close_message (&msg);
   return r;
 }
