@@ -521,7 +521,7 @@ int mutt_index_menu (void)
 	menu_status_line (buf, sizeof (buf), menu, NONULL (Status));
 	CLEARLINE (option (OPTSTATUSONTOP) ? 0 : LINES-2);
 	SETCOLOR (MT_COLOR_STATUS);
-	printw ("%-*.*s", COLS, COLS, buf);
+	mutt_paddstr (COLS, buf);
 	SETCOLOR (MT_COLOR_NORMAL);
 	menu->redraw &= ~REDRAW_STATUS;
       }
