@@ -261,7 +261,7 @@ struct option_t MuttVars[] = {
   ** When this variable is set, mutt will include Delivered-To headers when
   ** bouncing messages.  Postfix users may wish to unset this variable.
   */
-  { "charset",		DT_STR,	 R_NONE, UL &Charset, UL "iso-8859-1" },
+  { "charset",		DT_STR,	 R_NONE, UL &Charset, UL 0 },
   /*
   ** .pp
   ** Character set your terminal uses to display and enter textual data.
@@ -291,6 +291,23 @@ struct option_t MuttVars[] = {
   ** When \fIset\fP, Mutt will jump to the next unread message, if any,
   ** when the current thread is \fIun\fPcollapsed.
   */
+  { "compose_format",	DT_STR,	 R_BOTH, UL &ComposeFormat, UL "-- Mutt: Compose  [Approx. msg size: %l   Atts: %a]%>-" },
+  /*
+  ** .pp
+  ** Controls the format of the status line displayed in the \fCompose\fP
+  ** menu.  This string is similar to ``$$status_format'', but has its own
+  ** set of printf()-like sequences:
+  ** .pp
+  ** .ts
+  ** %a      total number of attachments 
+  ** %h      local hostname
+  ** %l      approximate size (in bytes) of the current message
+  ** %v      Mutt version string
+  ** .te
+  ** .pp
+  ** See the text describing the ``$$status_format'' option for more 
+  ** information on how to set ``$$compose_format''.
+  */
   { "confirmappend",	DT_BOOL, R_NONE, OPTCONFIRMAPPEND, 1 },
   /*
   ** .pp
@@ -328,7 +345,8 @@ struct option_t MuttVars[] = {
   { "default_hook",	DT_STR,	 R_NONE, UL &DefaultHook, UL "~f %s !~P | (~P ~C %s)" },
   /*
   ** .pp
-  ** This variable controls how send-hooks, save-hooks, and fcc-hooks will
+  ** This variable controls how send-hooks, display-hooks, save-hooks,
+  ** and fcc-hooks will
   ** be interpreted if they are specified with only a simple regexp,
   ** instead of a matching pattern.  The hooks are expanded when they are
   ** declared, so a hook will be interpreted according to the value of this
@@ -1406,7 +1424,7 @@ struct option_t MuttVars[] = {
   ** messages to an external Unix command.
   */
 #ifdef USE_POP
-  { "pop_delete",	DT_QUAD, R_NONE, OPTPOPDELETE, M_ASKNO },
+  { "pop_delete",	DT_QUAD, R_NONE, OPT_POPDELETE, M_ASKNO },
   /*
   ** .pp
   ** If set, Mutt will delete successfully downloaded messages from the POP
@@ -2214,6 +2232,7 @@ struct command_t Commands[] = {
   { "color",		mutt_parse_color,	0 },
   { "uncolor",		mutt_parse_uncolor,	0 },
 #endif
+  { "display-hook",	mutt_parse_hook,	M_DISPLAYHOOK },
   { "exec",		mutt_parse_exec,	0 },
   { "fcc-hook",		mutt_parse_hook,	M_FCCHOOK },
   { "fcc-save-hook",	mutt_parse_hook,	M_FCCHOOK | M_SAVEHOOK },
