@@ -28,11 +28,17 @@
 #include <limits.h>
 #include <stdarg.h>
 #include <signal.h>
+#ifdef HAVE_WCHAR_H
+#include <wchar.h>
+#endif
 
 #ifndef _POSIX_PATH_MAX
 #include <posix1_lim.h>
 #endif
 
+#include <pwd.h>
+#include <grp.h>
+
 #include "rfc822.h"
 #include "hash.h"
 
@@ -123,8 +129,9 @@ typedef enum
 #define M_FCCHOOK	(1<<3)
 #define M_SAVEHOOK	(1<<4)
 #define M_CHARSETHOOK	(1<<5)
+#define M_DISPLAYHOOK	(1<<6)
 #ifdef HAVE_PGP
-#define M_PGPHOOK	(1<<6)
+#define M_PGPHOOK	(1<<7)
 #endif
 
 /* tree characters for linearize_tree and print_enriched_string */
@@ -243,6 +250,7 @@ enum
   OPT_MIMEFWD,
   OPT_MOVE,
   OPT_COPY,
+  OPT_POPDELETE,
   OPT_POSTPONE,
   OPT_QUIT,
   OPT_REPLYTO,
@@ -323,7 +331,6 @@ enum
   OPTPAGERSTOP,
   OPTPIPEDECODE,
   OPTPIPESPLIT,
-  OPTPOPDELETE,
   OPTPOPLAST,
   OPTPRINTDECODE,
   OPTPROMPTAFTER,
@@ -480,6 +487,7 @@ typedef struct content
 {
   long hibin;              /* 8-bit characters */
   long lobin;              /* unprintable 7-bit chars (eg., control chars) */
+  long crlf;		   /* '\r' and '\n' characters */
   long ascii;              /* number of ascii chars */
   long linemax;            /* length of the longest line in the file */
   unsigned int space : 1;  /* whitespace at the end of lines? */
