@@ -969,15 +969,12 @@ static void encode_descriptions (BODY *b, short recurse)
 static void decode_descriptions (BODY *b)
 {
   BODY *t;
-  char tmp[LONG_STRING];
   
   for (t = b; t; t = t->next)
   {
     if (t->description)
     {
-      /* this should really have the same interface as rfc2047_encode_string. */
-      rfc2047_decode (tmp, t->description, sizeof (tmp));
-      mutt_str_replace (&t->description, tmp);
+      rfc2047_decode (&t->description);
     }
     if (t->parts)
       decode_descriptions (t->parts);
@@ -1048,19 +1045,6 @@ ci_send_message (int flags,		/* send mode */
   {
     msg = mutt_new_header ();
 
-#if 0
-    
-    /* this is no longer used. */
-    
-    if (flags == SENDRESEND)
-    {
-      if (mutt_prepare_template (fp, ctx, msg, cur, 1) < 0)
-	goto cleanup;
-    }
-    else
-
-#endif
-
     if (flags == SENDPOSTPONED)
     {
       if ((flags = mutt_get_postponed (ctx, msg, &cur, fcc, sizeof (fcc))) < 0)
@@ -1164,7 +1148,7 @@ ci_send_message (int flags,		/* send mode */
 
     /* change settings based upon recipients */
     
-    mutt_send_hook (msg);
+    mutt_message_hook (msg, M_SENDHOOK);
 
     if (killfrom)
     {
